@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-02-01 13:36:28 +0100 (Sun, 01 Feb 2004) $
- * $LastChangedRevision: 213 $
+ * $LastChangedDate: 2006-08-24 21:32:21 +0000 (Do, 24 Aug 2006) $
+ * $LastChangedRevision: 1248 $
  */
 
 #ifndef CHECK_H
@@ -29,7 +29,6 @@
 
 int check_deb (const char *target, di_package *package, const char *message);
 int check_md5 (const char *target, const char *md5sum, const char *message);
-int check_packages (const char *target, di_release *rel);
-int check_packages_extension (const char *target, const char *extension, di_release *rel);
+int check_packages (const char *target, const char *ext, di_release *rel);
 
 #endif
