@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-03-01 17:00:17 +0100 (Mo, 01 Mär 2004) $
- * $LastChangedRevision: 257 $
+ * $LastChangedDate: 2006-10-20 15:26:44 +0000 (Fr, 20 Okt 2006) $
+ * $LastChangedRevision: 1275 $
  */
 
 #ifndef DOWNLOAD_H
@@ -35,43 +35,30 @@
 
 static inline int build_target_deb_root (char *buf, size_t size, const char *file)
 {
-  snprintf (buf, size, "/var/cache/apt/archives/%s", file);
+  snprintf (buf, size, "/var/cache/bootstrap/%s", file);
   return 0;
 }
 
 static inline int build_target_deb (char *buf, size_t size, const char *file)
 {
-  snprintf (buf, size, "%s/var/cache/apt/archives/%s", install_root, file);
+  snprintf (buf, size, "%s/var/cache/bootstrap/%s", install_root, file);
   return 0;
 }
 
-static inline int build_source_indices_packages (char *buf, size_t size)
+static inline int build_indices (const char *file, char *source, size_t source_size, char *target, size_t target_size)
 {
-  snprintf (buf, size, "dists/%s/main/binary-%s/Packages", suite_name, arch);
+  snprintf (source, source_size, "dists/%s/main/binary-%s/%s", suite_name, arch, file);
+  snprintf (target, target_size, "%s/var/cache/bootstrap/_dists_._main_binary-%s_%s", install_root, arch, file);
   return 0;
 }
 
-static inline int build_target_indices_packages (char *buf, size_t size)
+static inline void build_indices_root (const char *file, char *source, size_t source_size, char *target, size_t target_size)
 {
-  snprintf (buf, size,
-            "%s/var/lib/apt/lists/debootstrap.invalid_dists_%s_main_binary-%s_Packages",
-            install_root, suite_name, arch);
-  return 0;
+  snprintf (source, source_size, "dists/%s/%s", suite_name, file);
+  snprintf (target, target_size, "%s/var/cache/bootstrap/_dists_._%s", install_root, file);
 }
 
-static inline int build_source_indices_release (char *buf, size_t size)
-{
-  snprintf (buf, size, "dists/%s/Release", suite_name);
-  return 0;
-}
-
-static inline int build_target_indices_release (char *buf, size_t size)
-{
-  snprintf (buf, size, "%s/var/lib/apt/lists/debootstrap.invalid_dists_%s_Release", install_root, suite_name);
-  return 0;
-}
-
-int download (di_packages **packages, di_packages_allocator *allocator, di_slist **install);
+int download (di_packages **packages, di_packages_allocator **allocator, di_slist **install);
 
 int download_init (void);
 
