@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2005-01-14 22:34:27 +0100 (Fr, 14 Jan 2005) $
- * $LastChangedRevision: 806 $
+ * $LastChangedDate: 2006-08-24 19:40:20 +0000 (Do, 24 Aug 2006) $
+ * $LastChangedRevision: 1243 $
  */
 
 #ifndef INSTALL_H
@@ -52,6 +52,7 @@ int install_helper_execute (const char *name);
 int install_helper_install (const char *name);
 int install_helper_remove (const char *name);
 
+int install_mount_dev (void);
 int install_mount_proc (void);
 void install_umount (void);
 
