@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-09-19 12:03:45 +0200 (So, 19 Sep 2004) $
- * $LastChangedRevision: 628 $
+ * $LastChangedDate: 2006-10-20 12:21:07 +0000 (Fr, 20 Okt 2006) $
+ * $LastChangedRevision: 1273 $
  */
 
 #ifndef SUITE_H
@@ -34,7 +34,7 @@ extern const char *flavour;
 extern const char *suite_name;
 extern const char *configdir;
 
-int suite_init (const char *suite_name, const char *arch, const char *flavour, const char **include, unsigned int include_size, const char *configdir);
+int suite_init (const char *suite_name, const char *suite_config_name, const char *arch, const char *flavour, const char **include, unsigned int include_size, const char *configdir);
 int suite_init_second (const char *suite_name);
 int suite_install (di_packages *packages, di_packages_allocator *allocator, di_slist *install);
 di_slist *suite_packages_list (di_packages *packages, di_packages_allocator *allocator);
