@@ -18,13 +18,14 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-13 11:11:34 +0200 (Sun, 13 Jun 2004) $
- * $LastChangedRevision: 454 $
+ * $LastChangedDate: 2006-10-20 15:26:44 +0000 (Fr, 20 Okt 2006) $
+ * $LastChangedRevision: 1275 $
  */
 
 #include <config.h>
 
 #include "download.h"
+#include "execute.h"
 #include "frontend.h"
 #include "install.h"
 #include "prepare.h"
@@ -47,9 +48,12 @@ int frontend_download (const char *source, const char *target)
   return WEXITSTATUS (ret);
 }
 
-int frontend_main (int argc __attribute__ ((unused)), char **argv)
+int frontend_main (int argc __attribute__ ((unused)), char **argv, char **envp)
 {
   char *suite;
+  static di_packages *packages;
+  static di_packages_allocator *allocator;
+  static di_slist *list;
 
   di_init (basename (argv[0]));
 
@@ -63,14 +67,19 @@ int frontend_main (int argc __attribute__ ((unused)), char **argv)
 
   if (install_target_check ("/target"))
     log_text (DI_LOG_LEVEL_ERROR, "target check");
-  if (suite_init (suite, DEB_ARCH, "standard", NULL, 0, CONFIGDIR))
+  if (suite_init (suite, NULL, DEB_ARCH, "standard", NULL, 0, CONFIGDIR))
     log_text (DI_LOG_LEVEL_ERROR, "suite init");
+  if (execute_init (envp))
+    log_text (DI_LOG_LEVEL_ERROR, "execute init");
   if (download_init ())
     log_text (DI_LOG_LEVEL_ERROR, "download init");
-  if (install_init ())
+  if (install_init (CONFIGDIR))
     log_text (DI_LOG_LEVEL_ERROR, "install init");
-  if (backend_main (false))
-    log_text (DI_LOG_LEVEL_ERROR, "backend");
+
+  if (download (&packages, &allocator, &list))
+    log_text (DI_LOG_LEVEL_ERROR, "download");
+  if (install (packages, allocator, list))
+    log_text (DI_LOG_LEVEL_ERROR, "install");
   return 0;
 }
 
