@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2006-10-20 15:26:44 +0000 (Fr, 20 Okt 2006) $
+ * $LastChangedRevision: 1275 $
  */
 
 #include <config.h>
@@ -27,16 +27,8 @@
 #include <signal.h>
 #include <stdlib.h>
 
-#include "download.h"
 #include "frontend.h"
 #include "install.h"
-#include "packages.h"
-#include "prepare.h"
-#include "suite.h"
-
-static di_packages *packages;
-static di_packages_allocator *allocator;
-static di_slist *list;
 
 void cleanup_atexit (void)
 {
@@ -50,7 +42,7 @@ void cleanup_signal (int signum __attribute__ ((unused)))
   exit (1);
 }
 
-int main (int argc, char **argv)
+int main (int argc, char **argv, char **envp)
 {
   atexit (cleanup_atexit);
   signal (SIGHUP, cleanup_signal);
@@ -58,32 +50,8 @@ int main (int argc, char **argv)
   signal (SIGPIPE, cleanup_signal);
   signal (SIGTERM, cleanup_signal);
 
-  if (frontend_main (argc, argv))
+  if (frontend_main (argc, argv, envp))
     log_text (DI_LOG_LEVEL_ERROR, "frontend died");
   return 0;
 }
 
-int backend_main (bool download_only)
-{
-  int ret;
-
-  frontend_progress_start (1000);
-
-  allocator = di_packages_allocator_alloc ();
-  if (!allocator)
-    return 1;
-  ret = download (&packages, allocator, &list);
-  if (ret)
-    return 1;
-
-  if (download_only)
-    return 0;
-
-  ret = install (packages, allocator, list);
-  if (ret)
-    return 1;
-  return 0;
-
-  frontend_progress_stop ();
-}
-
