@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2004-09-09 18:00:10 +0000 (Do, 09 Sep 2004) $
+ * $LastChangedRevision: 624 $
  */
 
 #include <config.h>
@@ -64,6 +64,14 @@ const di_parser_fieldinfo
       NULL,
       0
     ),
+  suite_config_action_field_flavour =
+    DI_PARSER_FIELDINFO
+    (
+      "Flavour",
+      parser_read_list,
+      NULL,
+      offsetof (suite_config_action, flavour)
+    ),
   suite_config_action_field_what =
     DI_PARSER_FIELDINFO
     (
@@ -133,6 +141,7 @@ static const di_parser_fieldinfo *suite_config_action_fieldinfo[] =
 {
   &suite_config_action_field_action,
   &suite_config_action_field_flags,
+  &suite_config_action_field_flavour,
   &suite_config_action_field_what,
   NULL
 };
